@@ -38,9 +38,9 @@ public:
     ColorSettings(TraceData* data, QWidget* parent);
     virtual ~ColorSettings();
 
-    bool check(QString&, QString&);
-    void accept();
-    void activate(QString s);
+    bool check(QString&, QString&) Q_DECL_OVERRIDE;
+    void accept() Q_DECL_OVERRIDE;
+    void activate(QString s) Q_DECL_OVERRIDE;
 
 public slots:
     void resetClicked();
